Crate matrix_sdk_sqlite

Crate matrix_sdk_sqlite 

Structs

SqliteEventCacheStore
An SQLite-based event cache store.
SqliteMediaStore
An SQLite-based media store.
SqliteStateStore
An SQLite-based state store.
SqliteStoreConfig
A configuration structure used for opening a store.

Enums

Base64Variant
Enum controlling how the high-entropy passphrase used to be created on the client side.
OpenStoreError
All the errors that can occur when opening an SQLite store.
Secret
An enum used to store the secret that gives access to a store

Constants

STATE_STORE_DATABASE_NAME
The filename used for the SQLITE database file used by the state store.